==> nonebot_plugin_l4d2_server-0.4.6.tar.gz: nonebot_plugin_l4d2_server-0.4.6/nonebot_plugin_l4d2_server/l4d2_queries/qqgroup.py <==
from ..l4d2_data.serverip import L4D2Server
from ..l4d2_image import server_ip_pic
from . import queries,player_queries,queries_dict,player_queries_anne_dict,msg_ip_to_list
from nonebot.log import logger
import random
import asyncio
import re
from ..message import PRISON,QUEREN,KAILAO
from .ohter import ALL_HOST
from typing import List,Dict
try:
    import ujson as json
except:
    import json
si = L4D2Server()
errors = (ConnectionRefusedError,ConnectionResetError,asyncio.exceptions.TimeoutError,OSError)
# errors = (TypeError,KeyError,ValueError,ConnectionResetError,TimeoutError)

async def get_qqgroup_ip_msg(qqgroup):
    """首先，获取qq群订阅数据，再依次queries返回ip原标"""
    ip_list = await si.query_server_ip(qqgroup)
    return ip_list
    
async def bind_group_ip(group:int,host:str,port:int):
    ip_list = await si.query_server_ip(group)
    if (host,port) in ip_list:
        return "本群已添加过该ip辣"
    await si.bind_server_ip(group,host,port)
    return "绑定成功喵，新增ip" + host

async def del_group_ip(group:int,number:int):
    number = int(number)
    logger.info(number)
    try:
        groups,host,port = await si.query_number(number)
    except TypeError:
        return '没有这个序号哦'
    if groups != group:
        return "本群可没有订阅过这个ip"
    await si.del_server_ip(number)
    return "取消成功喵，已删除序号" + str(number)
        
async def qq_ip_queries(msg:List[tuple]):
    """输入一个ip的二元元组组成的列表，返回一个输出消息的列表
    未来作图这里重置"""
    messsage = ""
    for i in msg:
        number,qqgroup,host,port = i
        msg2 = await player_queries(host,port)
        msg1 = await queries(host,port)
        messsage += '序号、'+ str(number) + '\n' + msg1 + msg2 + '--------------------\n'
    return messsage
            
            
async def qq_ip_querie(msg: list):
    msg_list = []
    tasks = []  # 用来保存异步任务
    if msg != []:
        for i in msg:
            try:
                number, host, port = i
                qqgroup = ''
            except ValueError:
                number, qqgroup, host, port = i
            finally:
                # 将异步任务添加到任务列表中
                tasks.append(asyncio.create_task(process_message(number, host, port, msg_list,qqgroup)))
        # 等待所有异步任务完成
        await asyncio.gather(*tasks)
        # 对msg_list按照number顺序排序
        msg_list.sort(key=lambda x: x['number'])
        result = {'msg_list': msg_list}

    else:
        result = {}
    return result


async def qq_ip_queries_pic(msg: list):
    result = await qq_ip_querie(msg)
    if 'msg_list' in result:
        pic = await server_ip_pic(result['msg_list'])
    else:
        pic = None
    return pic
            



async def process_message(number, host, port, msg_list:list,qqgroup = ''):
    try:
        msg2 = await player_queries_anne_dict(host, port)
        msg1 = await queries_dict(host, port)
        msg1.update({'Players':msg2,'number':number,})
        if qqgroup:
            msg1.update({'tag':qqgroup})
        msg_list.append(msg1)
    except errors:
        # 空白字典
        null_dict = {key: 'null' for key in ['name', 'map_', 'players', 'max_players', 'rank_players', 'ping']}
        null_dict.update({'number':number,'ip':f'{host}:{port}','Players':[]})
        msg_list.append(null_dict)  


    
async def get_tan_jian(msg:List[tuple],mode:int):
    """获取anne列表抽一个"""
    msg_list = []
    random.shuffle(msg)
    for i in msg:
        number,host,port = i
        try:
            if mode == 1:
                # 探监
                msg2 = await player_queries_anne_dict(host,port)
                point = 0
                for i in msg2:
                    point += int(i['Score'])
                logger.info(point)
                msg1 = await queries_dict(host,port)
                sp:str = msg1['name']
                if '特' not in sp:
                    continue
                sp = int(sp.split('特')[0].split('[')[-1])
                points = point/4
                if points/sp <10:
                    continue
                if 'HT' in msg1['name']:
                    continue
                msg1.update({'Players':msg2})
                msg1.update({'ranks':point})
                ips = f'{host}:{str(port)}'
                msg1.update({'ips':ips})
                # msg1是一行数据完整的字典
                msg_list.append(msg1)
            if mode == 2:
                # 坐牢
                # try:
                msg1 = await queries_dict(host,port)
                if '普通药役' in msg1['name']:
                    if '缺人' in msg1['name']:
                        msg2 = await player_queries_anne_dict(host,port)
                        msg1.update({'Players':msg2})
                        ips = f'{host}:{str(port)}'
                        msg1.update({'ips':ips})
                        # msg1是一行数据完整的字典
                    else:
                        continue
                else:
                    continue
                msg_list.append(msg1)
            if mode == 3:
                # 开牢
                msg1 = await queries_dict(host,port)
                if '[' not in msg1['name']:
                    msg2 = await player_queries_anne_dict(host,port)
                    msg1.update({'Players':msg2})
                    ips = f'{host}:{str(port)}'
                    msg1.update({'ips':ips})
                    # msg1是一行数据完整的字典
                    msg_list.append(msg1)
        except errors:
            continue
        if msg_list != []:
            break
    # 随机选一个牢房
    logger.info(msg_list)
    if len(msg_list) == 0:
        return '暂时没有这种牢房捏'
    logger.info(len(msg_list))
    mse = msg_list[0]
    message:str = ''
    if mode == 1:
        ranks = mse['ranks']
        if ranks <= 300 :
            message = random.choice(PRISON[1])
        if 300 < ranks <= 450 :
            message = random.choice(PRISON[2])
        if ranks > 450 :
            message = random.choice(PRISON[3]) 
    if mode == 2:
        player_point = mse['players']
        if player_point == '1':
            message = random.choice(QUEREN[1])
        elif player_point == '2':
            message = random.choice(QUEREN[2])
        elif player_point == '3':
            message = random.choice(QUEREN[3])
        else:
            message = random.choice(QUEREN[4])
    if mode == 3:
        message = random.choice(KAILAO)
    message += '\n' + '名称：' + mse['name'] + '\n'
    message += '地图：' + mse['map_'] + '\n'
    message += f"玩家：{mse['players']} / {mse['max_players']}\n"
    print(mse['Players'])
    try:
        message += await msg_ip_to_list(mse['Players'])
    except (KeyError):
        message += '服务器里，是空空的呢\n'
    message += 'connect ' + mse['ip']
    return message



async def get_server_ip(number):
    group,host,port = await si.query_number(number)
    try:
        return str(host) + ':' + str(port)
    except TypeError:
        return None

def split_maohao(msg:str) -> list:
    """分割大小写冒号"""
    msg:list = re.split(":|：",msg.strip())
    mse = [msg[0],msg[-1]] if msg[0] != msg[-1] else [msg[0],20715]
    return mse

async def write_json(data_str: str):
    """
    添加数据或者删除数据
     - 【求生更新 添加 腐竹 ip 模式 序号】
     - 【求生更新 添加 腐竹 ip 模式】
     - 【求生更新 删除 腐竹 序号】
    """
    data_list = data_str.split()
    logger.info(data_list)
    if data_list[0] == "添加":
        add_server = {}
        server_dict = ALL_HOST.get(data_list[1], {})
        if not server_dict:
            logger.info('新建分支')
            ALL_HOST[data_list[1]] = []
        for key, value in ALL_HOST.items():
            if data_list[1] == key:
                ids = [server['id'] for server in value]
                # 序号
                if len(data_list) == 4:
                    data_num = max(ids, default=0) + 1
                    add_server.update({'id': data_num})
                elif len(data_list) == 5:
                    if not data_list[4].isdigit():
                        return '序号应该为大于0的正整数，请输入【求生更新 添加 腐竹 ip 模式 序号】'
                    data_num = int(data_list[4])
                    if data_num in ids:
                        return '该序号已存在，请尝试删除原序号【求生更新 删除 腐竹 序号】'
                    add_server.update({'id': data_num})
                else:
                    return '输入参数错误，请输入【求生更新 添加 腐竹 ip 模式 序号】或【求生更新 添加 腐竹 ip 模式】'
                # 模式，ip
                try:
                    host, port = split_maohao(data_list[2])
                    add_server.update({'host': host, 'port': port})
                except KeyError:
                    return 'ip格式不正确【114.11.4.514:9191】'
                add_server.update({'version': data_list[3]})
                value.append(add_server)
                ALL_HOST[key] = value
                with open('data/L4D2/l4d2.json', 'w', encoding='utf8') as f_new:
                    json.dump(ALL_HOST, f_new, ensure_ascii=False, indent=4)
                return f'添加成功，指令为{key}{data_num}'
            
    elif data_list[0] == "删除":
        for key, value in ALL_HOST.items():
            if data_list[1] == key:
                try:
                    data_num = int(data_list[2])
                except ValueError:
                    return '序号应该为大于0的正整数，请输入【求生更新 删除 腐竹 序号】'
                for i, server in enumerate(value):
                    if data_num == server['id']:
                        value.pop(i)
                        if not value:
                            ALL_HOST.pop(key)
                        with open('data/L4D2/l4d2.json', 'w', encoding='utf8') as f_new:
                            json.dump(ALL_HOST, f_new, ensure_ascii=False, indent=4)
                        return '删除成功喵'
                return '序号不正确，请输入【求生更新 删除 腐竹 序号】'
        return '腐竹名不存在，请输入【求生更新 删除 腐竹 序号】'

==> nonebot_plugin_l4d2_server-0.5.7.post1.tar.gz: nonebot_plugin_l4d2_server-0.5.7.post1/nonebot_plugin_l4d2_server/l4d2_queries/qqgroup.py <==
from ..l4d2_data.serverip import L4D2Server
from ..l4d2_image import server_ip_pic
from . import queries,player_queries,queries_dict,player_queries_anne_dict,msg_ip_to_list,server_rule_dict
from nonebot.log import logger
import random
import asyncio
import re
from ..l4d2_utils.message import PRISON,QUEREN,KAILAO
from .ohter import ALL_HOST
from typing import List,Dict
try:
    import ujson as json
except:
    import json
si = L4D2Server()
errors = (ConnectionRefusedError,ConnectionResetError,asyncio.exceptions.TimeoutError,OSError)
# errors = (TypeError,KeyError,ValueError,ConnectionResetError,TimeoutError)

async def get_qqgroup_ip_msg(qqgroup):
    """首先，获取qq群订阅数据，再依次queries返回ip原标"""
    ip_list = await si.query_server_ip(qqgroup)
    return ip_list
    
async def bind_group_ip(group:int,host:str,port:int):
    ip_list = await si.query_server_ip(group)
    if (host,port) in ip_list:
        return "本群已添加过该ip辣"
    await si.bind_server_ip(group,host,port)
    return "绑定成功喵，新增ip" + host

async def del_group_ip(group:int,number:int):
    number = int(number)
    logger.info(number)
    try:
        groups,host,port = await si.query_number(number)
    except TypeError:
        return '没有这个序号哦'
    if groups != group:
        return "本群可没有订阅过这个ip"
    await si.del_server_ip(number)
    return "取消成功喵，已删除序号" + str(number)
        
async def qq_ip_queries(msg:List[tuple]):
    """输入一个ip的二元元组组成的列表，返回一个输出消息的列表
    未来作图这里重置"""
    messsage = ""
    for i in msg:
        number,qqgroup,host,port = i
        msg2 = await player_queries(host,port)
        msg1 = await queries(host,port)
        messsage += '序号、'+ str(number) + '\n' + msg1 + msg2 + '--------------------\n'
    return messsage
            
            
async def qq_ip_querie(msg: list,igr:bool = True):
    msg_list = []
    tasks = []  # 用来保存异步任务
    if msg != []:
        for i in msg:
            try:
                number, host, port = i
                qqgroup = ''
            except ValueError:
                number, qqgroup, host, port = i
            finally:
                # 将异步任务添加到任务列表中
                tasks.append(asyncio.create_task(process_message(number, host, port, msg_list,qqgroup,igr)))
        # 等待所有异步任务完成
        await asyncio.gather(*tasks)
        # 对msg_list按照number顺序排序
        msg_list.sort(key=lambda x: x['number'])
        for i in msg_list:
            print(i)
            break
        result = {'msg_list': msg_list}

    else:
        result = {}
    return result


async def qq_ip_queries_pic(msg: list,igr = False):
    result = await qq_ip_querie(msg,igr)
    print(result)
    if 'msg_list' in result:
        pic = await server_ip_pic(result['msg_list'])
    else:
        pic = None
    return pic
            



async def process_message(number, host, port, msg_list:list,igr:bool,qqgroup = ''):
    try:
        msg2 = await player_queries_anne_dict(host, port)
        msg1 = await queries_dict(host, port)
        msg3 = await server_rule_dict(host, port)
        msg1.update({'Players':msg2,'number':number,})
        msg1.update(msg3)
        if qqgroup:
            msg1.update({'tag':qqgroup})
        msg_list.append(msg1)
    except errors:
        if igr:
            pass
        else:
            # 空白字典
            null_dict = {key: 'null' for key in ['name', 'map_', 'players', 'max_players', 'rank_players', 'ping']}
            null_dict.update({'number':number,'ip':f'{host}:{port}','Players':[]})
            msg_list.append(null_dict)  


    
async def get_tan_jian(msg:List[tuple],mode:int):
    """获取anne列表抽一个"""
    msg_list = []
    random.shuffle(msg)
    for i in msg:
        number,host,port = i
        try:
            if mode == 1:
                # 探监
                msg2 = await player_queries_anne_dict(host,port)
                point = 0
                for i in msg2:
                    point += int(i['Score'])
                logger.info(point)
                msg1 = await queries_dict(host,port)
                sp:str = msg1['name']
                if '特' not in sp:
                    continue
                sp = int(sp.split('特')[0].split('[')[-1])
                points = point/4
                if points/sp <10:
                    continue
                if 'HT' in msg1['name']:
                    continue
                msg1.update({'Players':msg2})
                msg1.update({'ranks':point})
                ips = f'{host}:{str(port)}'
                msg1.update({'ips':ips})
                # msg1是一行数据完整的字典
                msg_list.append(msg1)
            if mode == 2:
                # 坐牢
                # try:
                msg1 = await queries_dict(host,port)
                if '普通药役' in msg1['name']:
                    if '缺人' in msg1['name']:
                        msg2 = await player_queries_anne_dict(host,port)
                        msg1.update({'Players':msg2})
                        ips = f'{host}:{str(port)}'
                        msg1.update({'ips':ips})
                        # msg1是一行数据完整的字典
                    else:
                        continue
                else:
                    continue
                msg_list.append(msg1)
            if mode == 3:
                # 开牢
                msg1 = await queries_dict(host,port)
                if '[' not in msg1['name']:
                    msg2 = await player_queries_anne_dict(host,port)
                    msg1.update({'Players':msg2})
                    ips = f'{host}:{str(port)}'
                    msg1.update({'ips':ips})
                    # msg1是一行数据完整的字典
                    msg_list.append(msg1)
        except errors:
            continue
        if msg_list != []:
            break
    # 随机选一个牢房
    logger.info(msg_list)
    if len(msg_list) == 0:
        return '暂时没有这种牢房捏'
    logger.info(len(msg_list))
    mse = msg_list[0]
    message:str = ''
    if mode == 1:
        ranks = mse['ranks']
        if ranks <= 300 :
            message = random.choice(PRISON[1])
        if 300 < ranks <= 450 :
            message = random.choice(PRISON[2])
        if ranks > 450 :
            message = random.choice(PRISON[3]) 
    if mode == 2:
        player_point = mse['players']
        if player_point == '1':
            message = random.choice(QUEREN[1])
        elif player_point == '2':
            message = random.choice(QUEREN[2])
        elif player_point == '3':
            message = random.choice(QUEREN[3])
        else:
            message = random.choice(QUEREN[4])
    if mode == 3:
        message = random.choice(KAILAO)
    message += '\n' + '名称：' + mse['name'] + '\n'
    message += '地图：' + mse['map_'] + '\n'
    message += f"玩家：{mse['players']} / {mse['max_players']}\n"
    print(mse['Players'])
    try:
        message += await msg_ip_to_list(mse['Players'])
    except (KeyError):
        message += '服务器里，是空空的呢\n'
    message += 'connect ' + mse['ip']
    return message



async def get_server_ip(number):
    group,host,port = await si.query_number(number)
    try:
        return str(host) + ':' + str(port)
    except TypeError:
        return None

def split_maohao(msg:str) -> list:
    """分割大小写冒号"""
    if ':' in msg:
        msg:list = msg.split(':')
    elif '：' in msg:
        msg:list = msg.split('：')
    elif msg.replace('.','').isdigit():
        msg:List[str] = [msg,'20715']
    else:
        pass  
    mse = [msg[0],msg[-1]]
    return mse

async def write_json(data_str: str):
    """
    添加数据或者删除数据
     - 【求生更新 添加 腐竹 ip 模式 序号】
     - 【求生更新 添加 腐竹 ip 模式】
     - 【求生更新 删除 腐竹 序号】
    """
    data_list = data_str.split()
    logger.info(data_list)
    if data_list[0] == "添加":
        add_server = {}
        server_dict = ALL_HOST.get(data_list[1], {})
        if not server_dict:
            logger.info('新建分支')
            ALL_HOST[data_list[1]] = []
        for key, value in ALL_HOST.items():
            if data_list[1] == key:
                ids = [server['id'] for server in value]
                # 序号
                if len(data_list) == 4:
                    data_num = max(ids, default=0) + 1
                    add_server.update({'id': data_num})
                elif len(data_list) == 5:
                    if not data_list[4].isdigit():
                        return '序号应该为大于0的正整数，请输入【求生更新 添加 腐竹 ip 模式 序号】'
                    data_num = int(data_list[4])
                    if data_num in ids:
                        return '该序号已存在，请尝试删除原序号【求生更新 删除 腐竹 序号】'
                    add_server.update({'id': data_num})
                else:
                    return '输入参数错误，请输入【求生更新 添加 腐竹 ip 模式 序号】或【求生更新 添加 腐竹 ip 模式】'
                # 模式，ip
                try:
                    host, port = split_maohao(data_list[2])
                    add_server.update({'host': host, 'port': port})
                except KeyError:
                    return 'ip格式不正确【114.11.4.514:9191】'
                add_server.update({'version': data_list[3]})
                value.append(add_server)
                ALL_HOST[key] = value
                with open('data/L4D2/l4d2.json', 'w', encoding='utf8') as f_new:
                    json.dump(ALL_HOST, f_new, ensure_ascii=False, indent=4)
                return f'添加成功，指令为{key}{data_num}'
            
    elif data_list[0] == "删除":
        for key, value in ALL_HOST.items():
            if data_list[1] == key:
                try:
                    data_num = int(data_list[2])
                except ValueError:
                    return '序号应该为大于0的正整数，请输入【求生更新 删除 腐竹 序号】'
                for i, server in enumerate(value):
                    if data_num == server['id']:
                        value.pop(i)
                        if not value:
                            ALL_HOST.pop(key)
                        with open('data/L4D2/l4d2.json', 'w', encoding='utf8') as f_new:
                            json.dump(ALL_HOST, f_new, ensure_ascii=False, indent=4)
                        return '删除成功喵'
                return '序号不正确，请输入【求生更新 删除 腐竹 序号】'
        return '腐竹名不存在，请输入【求生更新 删除 腐竹 序号】'
